@@ -33,8 +33,12 @@ class DjangoHttp404LogFilter(logging.Filter):
     PATTERN = re.compile("^Not Found:")
 
     def filter(self, record: logging.LogRecord) -> bool:
+        try:
+            message = record.msg % record.args
+        except TypeError:
+            message = record.msg
         is_not_found_record = (
-            self.PATTERN.match(record.msg) is not None
+            self.PATTERN.match(message) is not None
             and record.levelno == logging.WARNING
             and record.name.startswith("django")
         )
